pub(super) fn constraints_are_directly_unsat(
cx: &mut SymCx,
constraints: &[SymBoolExpr],
) -> boolExpand description
Returns whether normalized conjunctive constraints contain a direct contradiction.
pub(super) fn constraints_are_directly_unsat(
cx: &mut SymCx,
constraints: &[SymBoolExpr],
) -> boolReturns whether normalized conjunctive constraints contain a direct contradiction.